
import { Req } from '../http/request';
import { UserData } from '../storage';
import { HttpConfig } from '../http/server';
import { HttpWebDependencies } from './server';
import { csp_headers } from '../http/content-security-policy';
import { FastifyInstance, RouteShorthandOptions } from 'fastify';
import { render_template } from '../utilities/mustache';

export function register_root_page_endpoint(http_server: FastifyInstance, conf: HttpConfig, { session, logger }: HttpWebDependencies) {
	const opts: RouteShorthandOptions = {
		schema: { },
	};

	http_server.get('/', opts, async (req: Req, res) => {
		try {
			await session.check_login(req);
		}

		catch (error) {
			session.reset(res);
		}

		res.status(200);
		res.header('content-type', 'text/html; charset=utf-8');
		csp_headers(res, conf.exposed_url);
		return render_root_page(req.session?.user);
	});
}

function render_root_page(user: UserData) {
	const view = {
		user,
	};

	return render_template('root.html.mustache', view);
}
